# -*- coding: utf-8 -*-

# BCDI: tools for pre(post)-processing Bragg coherent X-ray diffraction imaging data
#   (c) 07/2017-06/2019 : CNRS UMR 7344 IM2NP
#   (c) 07/2019-05/2021 : DESY PHOTON SCIENCE
#   (c) 06/2021-present : DESY CFEL
#       authors:
#         Jerome Carnis, carnis_jerome@yahoo.fr
"""
BCDI and forward CDI preprocessing.

This package contains:
 - bcdi_utils: functions related to BCDI data preprocessing, before phase retrieval.
 - cdi_utils: functions related to forward CDI data preprocessing, before phase
  retrieval.
 - nxsReady, ReadNxs3: modules to load data at SIXS beamline

"""
